@@ -44,7 +44,7 @@ def generate_actions_from_irc_message(args,printer):
         printer("Monitoring channel" + channel, str(monitoring_channel))
 
     if debug:
-        printer("to_me: " + to_me + ", from_me: " + from_me + ", monitoring_channel: " + monitoring_channel,"")
+        printer("to_me: " + str(to_me) + ", from_me: " + str(from_me) + ", monitoring_channel: " + str(monitoring_channel),"")
 
     if not to_me and not from_me and monitoring_channel:
         elapsed_time = get_elapsed_time_on_channel(channel, monitored_channels)
